@@ -1,3 +1,3 @@
 """Main module."""
 def sum_square(x1,x2):
-    return(x1,x2)
+    return(x1**2+x2**2)
